<?php

use App\Models\AdminAdvert;
use App\Classes\{BBCode, Calendar, Metrika, CloudFlare};
use App\Models\Antimat;
use App\Models\Ban;
use App\Models\Banhist;
use App\Models\BlackList;
use App\Models\Blog;
use App\Models\Item;
use App\Models\Load;
use App\Models\Chat;
use App\Models\Counter;
use App\Models\Down;
use App\Models\Guestbook;
use App\Models\Invite;
use App\Models\Error;
use App\Models\News;
use App\Models\Notice;
use App\Models\Offer;
use App\Models\Online;
use App\Models\Photo;
use App\Models\Post;
use App\Models\Advert;
use App\Models\Setting;
use App\Models\Sticker;
use App\Models\Spam;
use App\Models\Topic;
use App\Models\User;
use App\Models\Vote;
use Curl\Curl;
use Illuminate\Database\Capsule\Manager as DB;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Lang;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Str;
use Intervention\Image\Constraint;
use Intervention\Image\ImageManagerStatic as Image;
use josegonzalez\Dotenv\Loader;
use ReCaptcha\ReCaptcha;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\ArrayInput;
use Symfony\Component\Console\Output\NullOutput;

/**
 * Форматирует вывод времени из секунд
 *
 * @param  string $time секунды
 *
 * @return string форматированный вывод
 */
function makeTime($time)
{
    $format = $time < 3600 ? 'i:s' : 'H:i:s';

    return gmdate($format, $time);
}

/**
 * Форматирует время с учетом часовых поясов
 *
 * @param int    $timestamp секунды
 * @param string $format    формат времени
 *
 * @return string форматированный вывод
 */
function dateFixed($timestamp, $format = 'd.m.y / H:i')
{
    if (! is_numeric($timestamp)) {
        $timestamp = SITETIME;
    }

    $shift     = getUser('timezone') * 3600;
    $dateStamp = date($format, $timestamp + $shift);

    $today     = date('d.m.y', SITETIME + $shift);
    $yesterday = date('d.m.y', strtotime('-1 day', SITETIME + $shift));

    $replaces = [
        $today      => __('main.today'),
        $yesterday  => __('main.yesterday'),
        'January'   => __('main.january'),
        'February'  => __('main.february'),
        'March'     => __('main.march'),
        'April'     => __('main.april'),
        'May'       => __('main.may'),
        'June'      => __('main.june'),
        'July'      => __('main.july'),
        'August'    => __('main.august'),
        'September' => __('main.september'),
        'October'   => __('main.october'),
        'November'  => __('main.november'),
        'December'  => __('main.december'),
    ];

    return strtr($dateStamp, $replaces);
}

/**
 * Конвертирует строку в кодировку utf-8
 *
 * @param string $str строка
 *
 * @return string конвертированная строка
 */
function winToUtf($str)
{
    return mb_convert_encoding($str, 'utf-8', 'windows-1251');
}

/**
 * Преобразует строку в нижний регистр
 *
 * @param string $str строка
 *
 * @return string преобразованная строка
 */
function utfLower($str)
{
    return mb_strtolower($str, 'utf-8');
}

/**
 * Обрезает строку
 *
 * @param string $str    строка
 * @param int    $start  начало позиции
 * @param int    $length конец позиции
 *
 * @return string обрезанная строка
 */
function utfSubstr($str, $start, $length = null)
{
    if (! $length) {
        $length = utfStrlen($str);
    }

    return mb_substr($str, $start, $length, 'utf-8');
}

/**
 * Возвращает длину строки
 *
 * @param string $str строка
 *
 * @return int длина строка
 */
function utfStrlen($str)
{
    return mb_strlen($str, 'utf-8');
}

/**
 * Определяет является ли кодировка utf-8
 *
 * @param string $str строка
 *
 * @return bool
 */
function isUtf($str)
{
    return mb_check_encoding($str, 'utf-8');
}

/**
 * Преобразует специальные символы в HTML-сущности
 *
 * @param mixed $string       строка или массив строк
 * @param bool  $doubleEncode преобразовывать существующие html-сущности
 *
 * @return mixed обработанные данные
 */
function check($string, $doubleEncode = true)
{
    if (is_array($string)) {
        foreach($string as $key => $val) {
            $string[$key] = check($val, $doubleEncode);
        }
    } else {
        $string = htmlspecialchars($string, ENT_QUOTES, 'UTF-8', $doubleEncode);
        $search = [chr(0), "\x00", "\x1A", chr(226) . chr(128) . chr(174)];
        $string = trim(str_replace($search, [], $string));
    }

    return $string;
}

/**
 * Преобразует в положительное число
 *
 * @param string $num число
 *
 * @return int обработанные данные
 */
function int($num)
{
    return (int) abs($num);
}

/**
 * Преобразует все элементы массива в int
 *
 * @param mixed $numbers массив или число
 *
 * @return array обработанные данные
 */
function intar($numbers)
{
    if ($numbers) {
        if (is_array($numbers)) {
            $numbers = array_map('intval', $numbers);
        } else {
            $numbers = [(int) $numbers];
        }
    }

    return $numbers;
}

/**
 * Возвращает размер в человекочитаемом формате
 *
 * @param int $bytes     размер в байтах
 * @param int $precision кол. символов после запятой
 *
 * @return string форматированный вывод размера
 */
function formatSize($bytes, $precision = 2)
{
    $units = ['B','Kb','Mb','Gb','Tb'];
    $pow   = floor(($bytes ? log($bytes) : 0) / log(1000));
    $pow   = min($pow, count($units) - 1);

    $bytes /= (1 << (10 * $pow));

    return round($bytes, $precision) . $units[$pow];
}

/**
 * Возвращает размер файла человекочитаемом формате
 *
 * @param string $file путь к файлу
 *
 * @return int|string размер в читаемом формате
 */
function formatFileSize($file)
{
    if (file_exists($file) && is_file($file)) {
        return formatSize(filesize($file));
    }

    return formatSize(0);
}

/**
 * Возвращает время в человекочитаемом формате
 *
 * @param int $time   кол. секунд timestamp
 * @param int $crumbs кол. элементов
 *
 * @return string время в читаемом формате
 */
function formatTime(int $time, int $crumbs = 2): string
{
    if ($time < 1) {
        return '0';
    }

    $units = [
        __('main.plural_years')   => 31536000,
        __('main.plural_months')  => 2592000,
        __('main.plural_days')    => 86400,
        __('main.plural_hours')   => 3600,
        __('main.plural_minutes') => 60,
        __('main.plural_seconds') => 1,
    ];

    $return = [];

    foreach ($units as $unit => $seconds) {
        $format = floor($time / $seconds);
        $time  %= $seconds;

        if ($format >= 1) {
            $return[] = plural($format, $unit);
        }
    }

    return implode(' ', array_slice($return, 0, $crumbs));
}

/**
 * Очищает строку от мата по базе слов
 *
 * @param string $str строка
 *
 * @return string обработанная строка
 */
function antimat($str)
{
    return Antimat::replace($str);
}

/**
 * Возвращает рейтинг в виде звезд
 *
 * @param float $rating рейтинг
 *
 * @return string преобразованный рейтинг
 */
function ratingVote($rating)
{
    $rating = round($rating / 0.5) * 0.5;

    $full_stars = floor($rating);
    $half_stars = ceil($rating - $full_stars);
    $empty_stars = 5 - $full_stars - $half_stars;

    $output = '<div class="star-rating fa-lg text-danger">';
    $output .= str_repeat('<i class="fas fa-star"></i>', $full_stars);
    $output .= str_repeat('<i class="fas fa-star-half-alt"></i>', $half_stars);
    $output .= str_repeat('<i class="far fa-star"></i>', $empty_stars);
    $output .= '( ' . $rating .' )</div>';

    return $output;
}

/**
 * Возвращает календарь
 *
 * @param int $time
 *
 * @return string календарь
 */
function getCalendar($time = SITETIME): string
{
    $calendar = new Calendar();

    return $calendar->getCalendar($time);
}

/**
 * Возвращает количество пользователей онлайн по типам
 *
 * @return array массив данных
 */
function statsOnline()
{
    return Cache::remember('online', 60, static function () {
        $online[] = Online::query()->whereNotNull('user_id')->count();
        $online[] = Online::query()->count();

        $metrika = new Metrika();
        $metrika->getCounter($online[1]);

        return $online;
    });
}

/**
 * Возвращает количество пользователей онлайн
 *
 * @return string
 */
function showOnline()
{
    $online = statsOnline();

    if (setting('onlines')) {
        return view('app/_online', compact('online'));
    }

    return null;
}

/**
 * Возвращает статистику посещений
 *
 * @return array статистика посещений
 */
function statsCounter()
{
    return Cache::remember('counter', 30, static function () {
        $counter = Counter::query()->first();

        return $counter ? $counter->toArray() : [];
    });
}

/**
 * Выводит счетчик посещений
 *
 * @return string
 */
function showCounter()
{
    $metrika = new Metrika();
    $metrika->saveStatistic();

    $counter = statsCounter();

    if (setting('incount') > 0) {
        return view('app/_counter', compact('counter'));
    }

    return null;
}

/**
 * Возвращает количество пользователей
 *
 * @return int количество пользователей
 */
function statsUsers()
{
    return Cache::remember('statUsers', 1800, static function () {
        $startDay = mktime(0, 0, 0, dateFixed(SITETIME, 'n'));

        $stat = User::query()->count();
        $new  = User::query()->where('created_at', '>', $startDay)->count();

        if ($new) {
            $stat .= '/+' . $new;
        }

        return $stat;
    });
}

/**
 * Возвращает количество администраторов
 *
 * @return int количество администраторов
 */
function statsAdmins()
{
    return Cache::remember('statAdmins', 3600, static function () {
        return User::query()->whereIn('level', User::ADMIN_GROUPS)->count();
    });
}

/**
 * Возвращает количество жалоб
 *
 * @return int количество жалоб
 */
function statsSpam()
{
    return Spam::query()->count();
}

/**
 * Возвращает количество забанненых пользователей
 *
 * @return int количество забаненных
 */
function statsBanned()
{
    return User::query()
        ->where('level', User::BANNED)
        ->where('timeban', '>', SITETIME)
        ->count();
}

/**
 * Возвращает количество записей в истории банов
 *
 * @return int количество записей
 */
function statsBanHist()
{
    return Banhist::query()->count();
}

/**
 * Возвращает количество ожидающих подтверждения регистрации
 *
 * @return int количество ожидающих
 */
function statsRegList()
{
    return User::query()->where('level', User::PENDED)->count();
}

/**
 * Возвращает количество забаненных по IP
 *
 * @return int количество забаненных
 */
function statsIpBanned()
{
    return Ban::query()->count();
}

/**
 * Возвращает количество фотографий в галерее
 *
 * @return int количество фотографий
 */
function statsPhotos()
{
    return Cache::remember('statPhotos', 900, static function () {
        $stat     = Photo::query()->count();
        $totalNew = Photo::query()->where('created_at', '>', strtotime('-3 day', SITETIME))->count();

        if ($totalNew) {
            $stat .= '/+' . $totalNew;
        }

        return $stat;
    });
}

/**
 * Возвращает количество новостей
 *
 * @return int количество новостей
 */
function statsNews()
{
    return Cache::remember('statNews', 300, static function () {
        return News::query()->count();
    });
}

/**
 * Возвращает количество записей в черном списке
 *
 * @return string количество записей
 */
function statsBlacklist()
{
    $blacklist = BlackList::query()
        ->selectRaw('type, count(*) as total')
        ->groupBy('type')
        ->pluck('total', 'type')
        ->all();

    $list = $blacklist + ['login' => 0, 'email' => 0, 'domain' => 0];

    return $list['login'] . '/' . $list['email'] . '/' . $list['domain'];
}

/**
 * Возвращает количество записей в антимате
 *
 * @return int количество записей
 */
function statsAntimat()
{
    return Antimat::query()->count();
}

/**
 * Возвращает количество стикеров
 *
 * @return int количество стикеров
 */
function statsStickers()
{
    return Sticker::query()->count();
}

/**
 * Возвращает дату последнего сканирования сайта
 *
 * @return int|string дата последнего сканирования
 */
function statsChecker()
{
    if (file_exists(STORAGE . '/caches/checker.php')) {
        return dateFixed(filemtime(STORAGE . '/caches/checker.php'), 'j.m.y');
    }

    return 0;
}

/**
 * Возвращает количество приглашений на регистрацию
 *
 * @return int количество приглашений
 */
function statsInvite()
{
    $invited     = Invite::query()->where('used', 0)->count();
    $usedInvited = Invite::query()->where('used', 1)->count();

    return $invited . '/' . $usedInvited;
}

/**
 * Возвращает следующею и предыдущую фотографию в галерее
 *
 * @param int $id Id фотографий
 *
 * @return mixed массив данных
 */
function photoNavigation($id)
{
    if (! $id) {
        return false;
    }

    $next = Photo::query()
        ->where('id', '>', $id)
        ->orderBy('id')
        ->pluck('id')
        ->first();

    $prev = Photo::query()
        ->where('id', '<', $id)
        ->orderByDesc('id')
        ->pluck('id')
        ->first();

    return compact('next', 'prev');
}

/**
 * Возвращает количество статей в блогах
 *
 * @return string количество статей
 */
function statsBlog()
{
    return Cache::remember('statBlogs', 900, static function () {
        $stat     = Blog::query()->count();
        $totalnew = Blog::query()->where('created_at', '>', strtotime('-3 day', SITETIME))->count();

        if ($totalnew) {
            $stat .= '/+' . $totalnew;
        }

        return $stat;
    });
}

/**
 * Возвращает количество тем и сообщений в форуме
 *
 * @return string количество тем и сообщений
 */
function statsForum()
{
    return Cache::remember('statForums', 600, static function () {
        $topics = Topic::query()->count();
        $posts  = Post::query()->count();

        return $topics . '/' . $posts;
    });
}

/**
 * Возвращает количество сообщений в гостевой книге
 *
 * @return int количество сообщений
 */
function statsGuestbook()
{
    return Cache::remember('statGuestbooks', 600, static function () {
        return Guestbook::query()->count();
    });
}

/**
 * Возвращает количество сообщений в админ-чате
 *
 * @return int количество сообщений
 */
function statsChat()
{
    return Chat::query()->count();
}

/**
 * Возвращает время последнего сообщения в админ-чате
 *
 * @return string время сообщения
 */
function statsNewChat()
{
    return Chat::query()->max('created_at');
}

/**
 * Возвращает количество файлов в загруз-центре
 *
 * @return string количество файлов
 */
function statsLoad()
{
    return Cache::remember('statLoads', 900, static function () {
        $totalLoads = Load::query()->sum('count_downs');

        $totalNew = Down::query()->where('active', 1)
            ->where('created_at', '>', strtotime('-3 day', SITETIME))
            ->count();

        return $totalNew ? $totalLoads . '/+' . $totalNew : $totalLoads;
    });
}

/**
 * Возвращает количество новых файлов
 *
 * @return string количество файлов
 */
function statsNewLoad()
{
    return Down::query()->where('active', 0)->count();
}

/**
 * Возвращает количество объявлений
 *
 * @return string количество статей
 */
function statsBoard()
{
    return Cache::remember('statBoards', 900, static function () {
        $stat      = Item::query()->where('expires_at', '>', SITETIME)->count();
        $totalnew  = Item::query()->where('updated_at', '>', strtotime('-3 day', SITETIME))->count();

        if ($totalnew) {
            $stat .= '/+' . $totalnew;
        }

        return $stat;
    });
}

/**
 * Обфусцирует email
 *
 * @param string $email email
 *
 * @return string обфусцированный email
 */
function cryptMail($email)
{
    $output  = '';
    $symbols = str_split($email);

    foreach ($symbols as $symbol) {
        $output  .= '&#' . ord($symbol) . ';';
    }

    return $output;
}

/**
 * Частично скрывает email
 *
 * @param string $email
 *
 * @return string
 */
function hideMail($email)
{
    return preg_replace('/(?<=.).(?=.*@)/u', '*', $email);
}

/**
 * Возвращает статистику текущих голосований из кэш-файла
 *
 * @return string Статистика текущий голосований
 */
function statVotes()
{
    return Cache::remember('statVotes', 900, static function () {
        $votes = Vote::query()
            ->selectRaw('count(*) AS cnt, ifnull(sum(count), 0) AS sum')
            ->where('closed', 0)
            ->first();

        if (! $votes) {
            $votes->cnt = $votes->sum = 0;
        }

        return $votes->cnt . '/' . $votes->sum;
    });
}

/**
 * Возвращает дату последней новости из кэш-файла
 *
 * @return string Дата последней новости
 */
function statsNewsDate()
{
    $newsDate = Cache::remember('statNewsDate', 900, static function () {
        $news = News::query()->orderByDesc('created_at')->first();

        return $news->created_at ?? 0;
    });

    return $newsDate ? dateFixed($newsDate, 'd.m.y') : 0;
}

/**
 * Кеширует последние новости
 *
 * @return string|void новость
 */
function statLastNews()
{
    if (setting('lastnews') > 0) {
        return Cache::remember('lastNews', 1800, static function () {
            return News::query()
                ->where('top', 1)
                ->orderByDesc('created_at')
                ->limit(setting('lastnews'))
                ->get()
                ->toArray();
        });
    }
}

/**
 * Возвращает последние новости
 *
 * @return string|void новость
 */
function lastNews()
{
    $news = statLastNews();

    if ($news) {
        foreach ($news as $data) {
            echo '<i class="far fa-circle fa-lg text-muted"></i> <a href="/news/' . $data['id'] . '">' . $data['title'] . '</a> (' . $data['count_comments'] . ') <i class="fas fa-angle-down news-title"></i><br>';

            if (strpos($data['text'], '[cut]') !== false) {
                $data['text'] = current(explode('[cut]', $data['text'])) . ' <a href="/news/'. $data['id'] .'" class="badge badge-success">Читать дальше &raquo;</a>';
            }

            echo '<div class="news-text" style="display: none;">' . bbCode($data['text']) . '<br>';
            echo '<a href="/news/comments/' . $data['id'] . '">Комментарии</a> ';
            echo '<a href="/news/end/' . $data['id'] . '">&raquo;</a></div>';
        }
    }
}

/**
 * Возвращает является ли пользователь авторизованным
 *
 * @return mixed
 */
function checkAuth()
{
    if (isset($_SESSION['id'], $_SESSION['password'])) {
        /** @var User $user */
        $user = User::query()->find($_SESSION['id']);

        if ($user && $_SESSION['password'] === md5(config('APP_KEY') . $user->password)) {
            return $user;
        }
    }

    return false;
}

/**
 * Возвращает является ли пользователь администратором
 *
 * @param string $level уровень доступа
 *
 * @return bool является ли пользователь администратором
 */
function isAdmin($level = User::EDITOR)
{
    return access($level);
}

/**
 * Возвращает имеет ли пользователь доступ по уровню
 *
 * @param string $level уровень доступа
 *
 * @return bool разрешен ли доступ
 */
function access($level)
{
    $access = array_flip(User::ALL_GROUPS);

    return getUser() && isset($access[$level], $access[getUser('level')]) && $access[getUser('level')] <= $access[$level];
}

/**
 * Возвращает иконку расширения
 *
 * @param string $ext расширение файла
 *
 * @return string иконка
 */
function icons($ext)
{
    switch ($ext) {
        case 'php':
            $ico = 'file-code';
            break;
        case 'ppt':
            $ico = 'file-powerpoint';
            break;
        case 'doc':
        case 'docx':
            $ico = 'file-word';
            break;
        case 'xls':
        case 'xlsx':
            $ico = 'file-excel';
            break;
        case 'txt':
        case 'css':
        case 'dat':
        case 'html':
        case 'htm':
            $ico = 'file-alt';
            break;
        case 'wav':
        case 'amr':
        case 'mp3':
        case 'mid':
            $ico = 'file-audio';
            break;
        case 'zip':
        case 'rar':
        case '7z':
        case 'gz':
            $ico = 'file-archive';
            break;
        case '3gp':
        case 'mp4':
            $ico = 'file-video';
            break;
        case 'jpg':
        case 'jpeg':
        case 'bmp':
        case 'wbmp':
        case 'gif':
        case 'png':
            $ico = 'file-image';
            break;
        case 'ttf':
            $ico = 'font';
            break;
        case 'pdf':
            $ico = 'file-pdf';
            break;
        default: $ico = 'file';
    }
    return '<i class="far fa-' . $ico . '"></i>';
}

/**
 * Перемешивает элементы ассоциативного массива, сохраняя ключи
 *
 * @param array &$array Исходный массив, переданный по ссылке
 *
 * @return bool Флаг успешного выполнения операции
 */
function shuffleAssoc(&$array)
{
    $keys = array_keys($array);

    shuffle($keys);
    $new = [];

    foreach($keys as $key) {
        $new[$key] = $array[$key];
    }

    $array = $new;
    return true;
}

/**
 * Закрывает bb-теги
 *
 * @param string $html
 *
 * @return string
 */
function closeTags(string $html): string
{
    preg_match_all('#\[([a-z]+)(?:=.*)?(?<![/])\]#iU', $html, $result);
    $openTags = $result[1];

    preg_match_all('#\[/([a-z]+)\]#iU', $html, $result);
    $closedTags = $result[1];

    if ($openTags === $closedTags) {
        return $html;
    }

    $diff = array_diff_assoc($openTags, $closedTags);
    $tags = array_reverse($diff);

    foreach ($tags as $key => $value) {
        $html .= '[/'. $value .']';
    }

    return $html;
}

/**
 * Возвращает обрезанный текст с закрытием тегов
 *
 * @param string $value
 * @param int    $words
 * @param string $end
 *
 * @return string
 */
function bbCodeTruncate(string $value, int $words = 20, string $end = '...'): string
{
    $value = Str::words($value, $words, $end);
    $value = bbCode(closeTags($value));

    return preg_replace('/\[(.*?)\]/', '', $value);
}

/**
 * Возвращает обрезанную до заданного количества букв строке
 *
 * @param string $value Исходная строка
 * @param int    $limit Максимальное количество символов в результате
 * @param string $end
 *
 * @return string Обрезанная строка
 */
function truncateString(string $value, int $limit = 100, string $end = '...'): string
{
    $value = strip_tags($value);

    if (mb_strlen($value, 'utf-8') <= $limit) {
        return $value;
    }

    $string = mb_substr($value, 0, $limit + 1);
    if ($lastSpace = mb_strrpos($string, ' ', 0, 'utf-8')) {
        $string = mb_substr($string, 0, $lastSpace, 'utf-8');
    } else {
        $string = mb_substr($string, 0, $limit, 'utf-8');
    }

    return trim($string) . $end;
}

/**
 * Возвращает обрезанную до заданного количества слов строке
 *
 * @param string $value Исходная строка
 * @param int    $words Максимальное количество слов в результате
 * @param string $end
 *
 * @return string Обрезанная строка
 */
function truncateWord(string $value, int $words = 20, string $end = '...'): string
{
    $value = strip_tags($value);

    return Str::words(trim($value), $words, $end);
}

/**
 * Возвращает обрезанную строку с удалением перевода строки
 *
 * @param string $value
 * @param int    $words
 * @param string $end
 *
 * @return string
 */
function truncateDescription(string $value, int $words = 20, string $end = ''): string
{
    $value = strip_tags(preg_replace('/\s+/', ' ', $value));

    return Str::words(trim($value), $words, $end);
}


/**
 * Возвращает HTML админской рекламы
 *
 * @return string
 */
function getAdvertAdmin()
{
    $adverts = AdminAdvert::statAdverts();

    if ($adverts) {
        $result  = Arr::random($adverts);
        return view('adverts/_admin_links', compact('result'));
    }

    return false;
}

/**
 * Возвращает HTML пользовательской рекламы
 *
 * @return string
 */
function getAdvertUser()
{
    $adverts = Advert::statAdverts();

    if ($adverts) {
        $total = count($adverts);
        $show  = setting('rekusershow') > $total ? $total : setting('rekusershow');

        $links  = Arr::random($adverts, $show);
        $result = implode('<br>', $links);

        return view('adverts/_links', compact('result'));
    }

    return false;
}

/**
 * Выводит последние фотографии
 *
 * @param int $show Количество последних фотографий
 *
 * @return string|void Список фотографий
 */
function recentPhotos($show = 5)
{
    $photos = Cache::remember('recentPhotos', 1800, static function () use ($show) {
        return Photo::query()
            ->orderByDesc('created_at')
            ->limit($show)
            ->with('files')
            ->get()
            ->toArray();
    });

    if ($photos) {
        foreach ($photos as $photo) {
            $file = current($photo['files']);

            if ($file) {
                echo '<a href="/photos/' . $photo['id'] . '">' . resizeImage($file['hash'], ['alt' => $photo['title'], 'class' => 'rounded', 'style' => 'width: 100px;']) . '</a>';
            }
        }

        echo '<br>';
    }
}

/**
 * Выводит последние темы форума
 *
 * @param int $show Количество последних тем форума
 *
 * @return string|void Список тем
 */
function recentTopics($show = 5)
{
    $topics = Cache::remember('recentTopics', 300, static function () use ($show) {
        return Topic::query()
            ->orderByDesc('updated_at')
            ->limit($show)
            ->get()
            ->toArray();
    });

    if ($topics) {
        foreach ($topics as $topic) {
            echo '<i class="far fa-circle fa-lg text-muted"></i>  <a href="/topics/' . $topic['id'] . '">' . $topic['title'] . '</a> (' . $topic['count_posts'] . ')';
            echo '<a href="/topics/end/' . $topic['id'] . '">&raquo;</a><br>';
        }
    }
}

/**
 * Выводит последние файлы в загрузках
 *
 * @param int $show Количество последних файлов в загрузках
 *
 * @return string|void Список файлов
 */
function recentDowns($show = 5)
{
    $files = Cache::remember('recentDowns', 600, static function () use ($show) {
        return Down::query()
            ->where('active', 1)
            ->orderByDesc('created_at')
            ->limit($show)
            ->with('category')
            ->get()
            ->toArray();
    });

    if ($files) {
        foreach ($files as $file) {
            echo '<i class="far fa-circle fa-lg text-muted"></i>  <a href="/downs/' . $file['id'] . '">' . $file['title'] . '</a> (' . $file['count_comments'] . ')<br>';
        }
    }
}

/**
 * Выводит последние статьи в блогах
 *
 * @param int $show Количество последних статей в блогах
 *
 * @return string|void Список статей
 */
function recentBlogs($show = 5)
{
    $blogs = Cache::remember('recentBlogs', 600, static function () use ($show) {
        return Blog::query()
            ->orderByDesc('created_at')
            ->limit($show)
            ->get()
            ->toArray();
    });

    if ($blogs) {
        foreach ($blogs as $blog) {
            echo '<i class="far fa-circle fa-lg text-muted"></i> <a href="/articles/' . $blog['id'] . '">' . $blog['title'] . '</a> (' . $blog['count_comments'] . ')<br>';
        }
    }
}

/**
 * Выводит последние объявления
 *
 * @param int $show Количество последних объявлений
 *
 * @return string|void Список объявлений
 */
function recentBoards($show = 5)
{
    $items = Cache::remember('recentBoards', 600, static function () use ($show) {
        return Item::query()
            ->where('expires_at', '>', SITETIME)
            ->orderByDesc('created_at')
            ->limit($show)
            ->get()
            ->toArray();
    });

    if ($items) {
        foreach ($items as $item) {
            echo '<i class="far fa-circle fa-lg text-muted"></i> <a href="/items/' . $item['id'] . '">' . $item['title'] . '</a><br>';
        }
    }
}


/**
 * Возвращает количество предложений и проблем
 *
 * @return string количество предложений и проблем
 */
function statsOffers()
{
    return Cache::remember('offers', 600, static function () {
        $offers   = Offer::query()->where('type', 'offer')->count();
        $problems = Offer::query()->where('type', 'issue')->count();

        return $offers . '/' . $problems;
    });
}

/**
 * Пересчитывает счетчики
 *
 * @param string $mode сервис счетчиков
 *
 * @return void
 */
function restatement($mode)
{
    switch ($mode) {
        case 'forums':
            DB::connection()->update('update topics set count_posts = (select count(*) from posts where topics.id = posts.topic_id)');
            DB::connection()->update('update forums set count_topics = (select count(*) from topics where forums.id = topics.forum_id)');
            DB::connection()->update('update forums set count_posts = (select ifnull(sum(count_posts), 0) from topics where forums.id = topics.forum_id)');
            break;

        case 'blogs':
            DB::connection()->update('update categories set count_blogs = (select count(*) from blogs where categories.id = blogs.category_id)');
            DB::connection()->update('update blogs set count_comments = (select count(*) from comments where relate_type = "' . addslashes(Blog::class) . '" and blogs.id = comments.relate_id)');
            break;

        case 'loads':
            DB::connection()->update('update loads set count_downs = (select count(*) from downs where loads.id = downs.category_id and active = ?)', [1]);
            DB::connection()->update('update downs set count_comments = (select count(*) from comments where relate_type = "' . addslashes(Down::class) . '" and downs.id = comments.relate_id)');
            break;

        case 'news':
            DB::connection()->update('update news set count_comments = (select count(*) from comments where relate_type = "' . addslashes(News::class) . '" and news.id = comments.relate_id)');
            break;

        case 'photos':
            DB::connection()->update('update photos set count_comments = (select count(*) from comments where relate_type = "' . addslashes(Photo::class) . '" and photos.id = comments.relate_id)');
            break;

        case 'offers':
            DB::connection()->update('update offers set count_comments = (select count(*) from comments where relate_type = "' . addslashes(Offer::class) . '" and offers.id = comments.relate_id)');
            break;

        case 'boards':
            DB::connection()->update('update boards set count_items = (select count(*) from items where boards.id = items.board_id and items.expires_at > ' . SITETIME . ');');
            break;

        case 'votes':
            DB::connection()->update('update votes set count = (select ifnull(sum(result), 0) from voteanswer where votes.id = voteanswer.vote_id)');
            break;
    }
}

/**
 * Возвращает количество строк в файле
 *
 * @param string $file путь к файлу
 *
 * @return int количество строк
 */
function counterString($file)
{
    $countLines = 0;
    if (file_exists($file)) {
        $countLines = count(file($file));
    }

    return $countLines;
}

/**
 * Форматирует вывод числа
 *
 * @param int $num число
 *
 * @return string форматированное число
 */
function formatNum($num)
{
    if ($num > 0) {
        return '<span style="color:#00aa00">+' . $num . '</span>';
    }

    if ($num < 0) {
        return '<span style="color:#ff0000">' . $num . '</span>';
    }

    return '<span>0</span>';
}

/**
 * Форматирует вывод числа
 *
 * @param int $num
 *
 * @return bool|string
 */
function formatShortNum($num)
{
    if (! is_numeric($num)) {
        return false;
    }

    if ($num > 1000000000000) {
        return round($num / 1000000000000, 1) . 'T';
    }

    if ($num > 1000000000) {
        return round($num / 1000000000, 1) . 'B';
    }

    if ($num > 1000000) {
        return round($num / 1000000, 1) . 'M';
    }

    if ($num > 1000) {
        return round($num / 1000, 1) . 'K';
    }

    return $num;
}

/**
 * Обрабатывает и уменьшает изображение
 *
 * @param string $path   путь к изображению
 * @param array  $params параметры изображения
 *
 * @return array обработанные параметры
 */
function resizeProcess($path, array $params = [])
{
    if (empty($params['alt'])) {
        $params['alt'] = basename($path);
    }

    if (empty($params['class'])) {
        $params['class'] = 'img-fluid';
    }

    if (empty($params['width'])) {
        $params['width'] = setting('previewsize');
    }

    if (! file_exists(HOME . $path) || ! is_file(HOME . $path)) {
        return [
            'path'   => '/assets/img/images/photo.png',
            'source' => false,
            'params' => $params,
        ];
    }

    [$width, $height] = getimagesize(HOME . $path);

    if ($width <= $params['width'] && $height <= $params['width']) {
        return [
            'path'   => $path,
            'source' => $path,
            'params' => $params,
        ];
    }

    $thumb = ltrim(str_replace('/', '_', $path), '_');

    if (! file_exists(UPLOADS . '/thumbnails/' . $thumb)) {
        $img = Image::make(HOME . $path);
        $img->resize($params['width'], $params['width'], static function (Constraint $constraint) {
            $constraint->aspectRatio();
            $constraint->upsize();
        });

        /*
        $img->fit($params['width'], $params['width'], function ($constraint) {
            $constraint->upsize();
        });*/

        $img->save(UPLOADS . '/thumbnails/' . $thumb);
    }

    return [
        'path'   => '/uploads/thumbnails/' . $thumb,
        'source' => $path,
        'params' => $params,
    ];
}

/**
 * Возвращает уменьшенное изображение
 *
 * @param string $path   путь к изображению
 * @param array  $params параметры изображения
 *
 * @return string уменьшенное изображение
 */
function resizeImage($path, array $params = [])
{
    $image = resizeProcess($path, $params);

    $strParams = [];
    foreach ($image['params'] as $key => $param) {
        $strParams[] = $key . '="' . $param . '"';
    }

    $strParams = implode(' ', $strParams);

    return '<img src="' . $image['path'] . '" data-source="' . $image['source'] . '" ' . $strParams . '>';
}

/**
 * Удаляет директорию рекурсивно
 *
 * @param string $dir путь к директории
 *
 * @return void
 */
function deleteDir($dir)
{
    if (file_exists($dir)) {
        if ($files = glob($dir . '/*')) {
            foreach($files as $file) {
                is_dir($file) ? deleteDir($file) : unlink($file);
            }
        }
        rmdir($dir);
    }
}

/**
 * Удаляет файл
 *
 * @param string $path путь к файлу
 *
 * @return bool
 */
function deleteFile(string $path)
{
    if (file_exists($path) && is_file($path)) {
        unlink($path);
    }

    if (in_array(getExtension($path), ['jpg', 'jpeg', 'gif', 'png'], true)) {
        $thumb = ltrim(str_replace([HOME, '/'], ['', '_'], $path), '_');
        $thumb = UPLOADS . '/thumbnails/' . $thumb;

        if (file_exists($thumb) && is_file($thumb)) {
            unlink($thumb);
        }
    }

    return true;
}

/**
 * Отправляет уведомление об упоминании в приват
 *
 * @param string $text  текст сообщения
 * @param string $url   путь к странице
 * @param string $title название страницу
 *
 * @return void
 */
function sendNotify(string $text, string $url, string $title)
{
    /*$parseText = preg_replace('|\[quote(.*?)\](.*?)\[/quote\]|s', '', $text);*/
    preg_match_all('/(?<=^|\s|=)@([\w\-]+)/', $text, $matches);

    if (! empty($matches[1])) {
        $usersAnswer = array_unique(array_diff($matches[1], [getUser('login')]));

        foreach ($usersAnswer as $login) {
            $user = getUserByLogin($login);
            if ($user && $user->notify) {
                $notify = textNotice('notify', ['login' => getUser('login'), 'url' => $url, 'title' => $title, 'text' => $text]);
                $user->sendMessage(null, $notify);
            }
        }
    }
}

/**
 * Возвращает приватное сообщение
 *
 * @param string $type    тип сообщения
 * @param array  $replace массив заменяемых параметров
 *
 * @return string сформированный текст
 */
function textNotice($type, array $replace = [])
{
    $message = Notice::query()->where('type', $type)->first();

    if (! $message) {
        return __('main.text_missing');
    }

    foreach ($replace as $key => $val) {
        $message->text = str_replace('%' . $key . '%', $val, $message->text);
    }

    return $message->text;
}

/**
 * Возвращает блок статистики производительности
 *
 * @return string статистика производительности
 */
function performance()
{
    if (isAdmin() && setting('performance')) {
        $queries = getQueryLog();
        $timeQueries = array_sum(array_column($queries, 'time'));

        return view('app/_performance', compact('queries', 'timeQueries'));
    }

    return null;
}

/**
 * Очистка кеш-файлов
 *
 * @param string|array $keys
 *
 * @return bool результат выполнения
 */
function clearCache($keys = null)
{
    if ($keys) {
        if (!is_array($keys)) {
            $keys = [$keys];
        }

        foreach ($keys as $key) {
            Cache::forget($key);
        }

        return true;
    }

    Cache::flush();

    return true;
}

/**
 * Возвращает текущую страницу
 *
 * @param string $url
 *
 * @return string текущая страница
 */
function returnUrl($url = null)
{
    $request = request();

    if ($request->is('/', 'login', 'register', 'recovery', 'restore', 'ban', 'closed')) {
        return false;
    }

    $query = $request->has('return') ? $request->input('return') : $request->path();

    return '?return=' . urlencode($url ?? '/' . $query);
}

/**
 * Возвращает подключенный шаблон
 *
 * @param string $view   имя шаблона
 * @param array  $params массив параметров
 * @param array  $mergeData
 *
 * @return string сформированный код
 */
function view($view, array $params = [], array $mergeData = []): string
{
    return View::make($view, $params, $mergeData)->render();
}

/**
 * Translate the given message.
 *
 * @param string $key
 * @param array  $replace
 * @param string $locale
 *
 * @return string
 */
function __($key, array $replace = [], $locale = null)
{
    return Lang::get($key, $replace, $locale);
}

/**
 * Translates the given message based on a count.
 *
 * @param string              $key
 * @param int|array|Countable $number
 * @param array               $replace
 * @param string              $locale
 *
 * @return string
 */
function choice($key, $number, array $replace = [], $locale = null)
{
    return Lang::choice($key, $number, $replace, $locale);
}

/**
 * Сохраняет страницы с ошибками
 *
 * @param int    $code    код ошибки
 * @param string $message текст ошибки
 *
 * @return string сформированная страница с ошибкой
 */
function abort($code, $message = null)
{
    $protocol = server('SERVER_PROTOCOL');
    $referer  = server('HTTP_REFERER');

   switch ($code) {
       case 403:
           header($protocol . ' 403 Forbidden');
           break;
       case 404:
           header($protocol . ' 404 Not Found');
           break;
       case 405:
           header($protocol . ' 405 Method Not Allowed');
           break;
       default:
           header($protocol . ' 400 Bad Request');
           break;
   }

    saveErrorLog($code);

    if (request()->ajax()) {
        header($protocol . ' 200 OK');

        exit(json_encode([
            'status' => 'error',
            'message' => $message,
        ]));
    }

    exit(view('errors/' . $code, compact('message', 'referer')));
}

/**
 * Saves error logs
 *
 * @param mixed $code
 *
 * @return void
 */
function saveErrorLog($code)
{
    if (setting('errorlog') && in_array($code, [403, 404, 405, 666], true)) {
        Error::query()->create([
            'code'       => $code,
            'request'    => utfSubstr(server('REQUEST_URI'), 0, 200),
            'referer'    => utfSubstr(server('HTTP_REFERER'), 0, 200),
            'user_id'    => getUser('id'),
            'ip'         => getIp(),
            'brow'       => getBrowser(),
            'created_at' => SITETIME,
        ]);
    }
}

/**
 * Переадресовывает пользователя
 *
 * @param string $url       адрес переадресации
 * @param bool   $permanent постоянное перенаправление
 *
 * @return void
 */
function redirect($url, $permanent = false)
{
    if (isset($_SESSION['captcha'])) {
        $_SESSION['captcha'] = null;
    }

    if ($permanent) {
        header($_SERVER['SERVER_PROTOCOL'] . ' 301 Moved Permanently');
    }

    header('Location: ' . $url);
    exit();
}

/**
 * Сохраняет flash уведомления
 *
 * @param string $status статус уведомления
 * @param mixed  $message массив или текст с уведомлениями
 *
 * @return void
 */
function setFlash($status, $message)
{
    $_SESSION['flash'][$status] = $message;
}

/**
 * Возвращает ошибку
 *
 * @param mixed $errors ошибки
 *
 * @return string сформированный блок с ошибкой
 */
function showError($errors)
{
    if (is_array($errors)) {
        $errors = implode('<br><i class="fa fa-exclamation-circle fa-lg text-danger"></i> ', $errors);
    }

    return view('app/_error', compact('errors'));
}

/**
 * Сохраняет POST данные введенных пользователем
 *
 * @param array $data массив полей
 */
function setInput(array $data)
{
    $_SESSION['input'] = json_encode($data);
}

/**
 * Возвращает значение из POST данных
 *
 * @param string $name имя поля
 * @param string $default
 *
 * @return mixed сохраненное значение
 */
function getInput($name, $default = null)
{
    if (empty($_SESSION['input'])) {
        return $default;
    }

    $session = json_decode($_SESSION['input'], true);
    $input   = Arr::get($session, $name);

    if ($input !== null) {
        Arr::forget($session, $name);

        $_SESSION['input'] = json_encode($session);
    }

    return $input ?? $default;
}

/**
 * Подсвечивает блок с полем для ввода сообщения
 *
 * @param string $field имя поля
 *
 * @return string CSS класс ошибки
 */
function hasError($field)
{
    $isValid = isset($_SESSION['flash']['danger']) ? ' is-valid' : '';

    return isset($_SESSION['flash']['danger'][$field]) ? ' is-invalid' : $isValid;
}

/**
 * Возвращает блок с текстом ошибки
 *
 * @param string $field имя поля
 *
 * @return string блоки ошибки
 */
function textError($field)
{
    return $_SESSION['flash']['danger'][$field] ?? null;
}

/**
 * Отправляет уведомления на email
 *
 * @param mixed  $to      Получатель
 * @param string $subject Тема письма
 * @param string $body    Текст сообщения
 * @param array  $params  Дополнительные параметры
 *
 * @return bool Результат отправки
 */
function sendMail($to, $subject, $body, array $params = [])
{
    if (empty($params['from'])) {
        $params['from'] = [config('SITE_EMAIL') => config('SITE_ADMIN')];
    }

    $message = (new Swift_Message())
        ->setTo($to)
        ->setSubject($subject)
        ->setBody($body, 'text/html')
        ->setFrom($params['from'])
        ->setReturnPath(config('SITE_EMAIL'));

    if (config('MAIL_DRIVER') === 'smtp') {
        $transport = (new Swift_SmtpTransport())
            ->setHost(config('MAIL_HOST'))
            ->setPort(config('MAIL_PORT'))
            ->setEncryption(config('MAIL_ENCRYPTION'))
            ->setUsername(config('MAIL_USERNAME'))
            ->setPassword(config('MAIL_PASSWORD'));
    } else {
        $transport = new Swift_SendmailTransport();

        if (config('MAIL_PATH')) {
            $transport->setCommand(config('MAIL_PATH'));
        }
    }

    $mailer = new Swift_Mailer($transport);

    try {
        return $mailer->send($message);
    } catch (Exception $e) {
        return false;
    }
}

/**
 * Возвращает расширение файла
 *
 * @param string $filename имя файла
 *
 * @return string расширение
 */
function getExtension($filename)
{
    return pathinfo($filename, PATHINFO_EXTENSION);
}

/**
 * Возвращает имя файла без расширения
 *
 * @param string $filename имя файла
 *
 * @return string имя без расширения
 */
function getBodyName($filename)
{
    return pathinfo($filename, PATHINFO_FILENAME);
}

/**
 * Склоняет числа
 *
 * @param int   $num   число
 * @param mixed $forms массив склоняемых слов (один, два, много)
 *
 * @return string форматированная строка
 */
function plural($num, $forms)
{
    if (! is_array($forms)) {
        $forms = explode(',', $forms);
    }

    if (count($forms) === 1) {
        return $num . ' ' . $forms[0];
    }

    if ($num % 100 > 10 &&  $num % 100 < 15) {
        return $num . ' ' . $forms[2];
    }

    if ($num % 10 === 1) {
        return $num . ' ' . $forms[0];
    }

    if ($num % 10 > 1 && $num % 10 < 5) {
        return $num . ' ' . $forms[1];
    }

    return $num . ' ' . $forms[2];
}

/**
 * Обрабатывает BB-код
 *
 * @param string $text  Необработанный текст
 * @param bool   $parse Обрабатывать или вырезать код
 *
 * @return string Обработанный текст
 */
function bbCode($text, $parse = true)
{
    $bbCode = new BBCode();

    if (! $parse) {
        return $bbCode->clear($text);
    }

    $text = $bbCode->parse($text);
    $text = $bbCode->parseStickers($text);

    return $text;
}

/**
 * Определяет IP пользователя
 *
 * @return string IP пользователя
 */
function getIp()
{
    $cf = new CloudFlare(request());
    $ip = $cf->ip();

    return $ip === '::1' ? '127.0.0.1' : $ip;
}

/**
 * Определяет браузер
 *
 * @param string|null $userAgent
 *
 * @return string браузер и версия браузера
 */
function getBrowser($userAgent = null)
{
    $browser = new Browser();
    if ($userAgent) {
        $browser->setUserAgent($userAgent);
    }

    $brow = $browser->getBrowser();
    $version = implode('.', array_slice(explode('.', $browser->getVersion()), 0, 2));
    return mb_substr($version === 'unknown' ? $brow : $brow . ' ' . $version, 0, 25, 'utf-8');
}

/**
 * Возращает объект Request
 *
 * @return Request
 */
function request(): Request
{
    static $request;

    if (! $request) {
        $request = Request::capture();
    }

    return $request;
}

/**
 * Возвращает серверные переменные
 *
 * @param string|null $key     ключ массива
 * @param string|null $default значение по умолчанию
 *
 * @return mixed данные
 */
function server($key = null, $default = null)
{
    $server = request()->server($key, $default);

    if ($key === 'REQUEST_URI') {
        $server = urldecode($server);
    }

    if ($key === 'PHP_SELF') {
        $server = current(explode('?', server('REQUEST_URI')));
    }

    return check($server);
}

/**
 * Возвращает объект пользователя по логину
 *
 * @param string $login логин пользователя
 *
 * @return Builder|Model|null
 */
function getUserByLogin($login): ?User
{
    return User::query()->where('login', $login)->first();
}

/**
 * Возвращает объект пользователя по id
 *
 * @param int $id ID пользователя
 *
 * @return Builder|Model|null
 */
function getUserById(int $id): ?User
{
    return User::query()->find($id);
}

/**
 * Возвращает объект пользователя по логину или email
 *
 * @param string $login логин или email пользователя
 *
 * @return Builder|Model|null
 */
function getUserByLoginOrEmail($login): ?User
{
    $field = strpos($login, '@') ? 'email' : 'login';

    return User::query()->where($field, $login)->first();
}

/**
 * Возвращает данные пользователя по ключу
 *
 * @param string $key ключ массива
 *
 * @return User|mixed
 */
function getUser($key = null)
{
    static $user;

    if (! $user) {
        $user = checkAuth();
    }

    return $key ? ($user[$key] ?? null) : $user;
}

/**
 * Разбивает массив по страницам
 *
 * @param array $items
 * @param int   $perPage
 * @param array $appends
 *
 * @return LengthAwarePaginator
 */
function paginate(array $items, int $perPage, array $appends = []): LengthAwarePaginator
{
    $currentPage = LengthAwarePaginator::resolveCurrentPage();
    $slice       = array_slice($items, $perPage * ($currentPage - 1), $perPage, true);

    $collection = new LengthAwarePaginator($slice, count($items), $perPage);
    $collection->setPath(request()->url());
    $collection->appends($appends);

    return $collection;
}

/**
 * Возвращает сформированный код base64 картинки
 *
 * @param string $path   путь к картинке
 * @param array  $params параметры
 *
 * @return string сформированный код
 */
function imageBase64($path, array $params = [])
{
    $type = getExtension($path);
    $data = file_get_contents($path);

    if (! isset($params['class'])) {
        $params['class'] = 'img-fluid';
    }

    if (empty($params['alt'])) {
        $params['alt'] = basename($path);
    }

    $strParams = [];
    foreach ($params as $key => $param) {
        $strParams[] = $key . '="' . $param . '"';
    }

    $strParams = implode(' ', $strParams);

    return '<img src="data:image/' . $type . ';base64,' . base64_encode($data) . '"' . $strParams . '>';
}

/**
 * Выводит прогресс-бар
 *
 * @param int    $percent
 * @param string $title
 *
 * @return string
 */
function progressBar($percent, $title = null)
{
    if (! $title) {
        $title = $percent . '%';
    }

    return view('app/_progressbar', compact('percent', 'title'));
}

/**
 * Возвращает форматированный список запросов
 *
 * @return array
 */
function getQueryLog()
{
    $queries = DB::connection()->getQueryLog();
    $formattedQueries = [];
    foreach ($queries as $query) {
        $prep = $query['query'];
        foreach ($query['bindings'] as $binding) {
            $binding = is_int($binding) ? $binding : "'{$binding}'";
            $prep = preg_replace("#\?#", $binding, $prep, 1);
        }
        $formattedQueries[] = ['query' => $prep, 'time' => $query['time']];
    }

    return $formattedQueries;
}

/**
 * Выводит список забаненных ip
 *
 * @param bool $clear нужно ли сбросить кеш
 *
 * @return array массив IP
 */
function ipBan($clear = false)
{
    if ($clear) {
        clearCache('ipBan');
    }

    return Cache::rememberForever('ipBan', static function () {
        return Ban::query()->pluck('ip')->all();
    });
}

/**
 * Возвращает пользовательские настройки сайта по ключу
 *
 * @param string $key     ключ массива
 * @param string $default значение по умолчанию
 *
 * @return mixed данные
 */
function setting($key = null, $default = null)
{
    static $settings;

    if (! $settings) {
        $settings = array_replace(Setting::getSettings(), Setting::getUserSettings());
    }

    return $key ? ($settings[$key] ?? $default) : $settings;
}

/**
 * Возвращает дефолтные настройки сайта по ключу
 *
 * @param string $key     ключ массива
 * @param string $default значение по умолчанию
 *
 * @return mixed данные
 */
function defaultSetting($key = null, $default = null)
{
    static $settings;

    if (! $settings) {
        $settings = Setting::getSettings();
    }

    return $key ? ($settings[$key] ?? $default) : $settings;
}

/**
 * Возвращает путь к сайту
 *
 * @param bool $parse выводить протокол
 *
 * @return string адрес сайта
 */
function siteUrl($parse = false)
{
    $url = config('SITE_URL');

    if ($parse) {
        $url = Str::startsWith($url, '//') ? 'http:' . $url : $url;
    }

    return $url;
}

/**
 * Возвращает имя сайта из ссылки
 *
 * @param string $url ссылка на сайт
 *
 * @return string имя сайта
 */
function siteDomain($url)
{
    $url = strtolower($url);
    $url = str_replace(['http://www.', 'http://', 'https://', '//'], '', $url);
    $url = strtok($url, '/?');

    return $url;
}

/**
 * Получает версию
 *
 * @param string $version
 *
 * @return string
 */
function parseVersion($version)
{
    $ver = explode('.', strtok($version, '-'));

    return $ver[0] . '.' . $ver[1] . '.' . ($ver[2] ?? 0);
}

/**
 * Проверяет captcha
 *
 * @return bool
 */
function captchaVerify(): bool
{
    $request = request();

    if (setting('captcha_type') === 'recaptcha_v2') {
        $recaptcha = new ReCaptcha(setting('recaptcha_private'));

        $response = $recaptcha->setExpectedHostname($_SERVER['SERVER_NAME'])
            ->verify($request->input('g-recaptcha-response'), getIp());

        return $response->isSuccess();
    }

    if (setting('captcha_type') === 'recaptcha_v3') {
        $recaptcha = new ReCaptcha(setting('recaptcha_private'));

        $response = $recaptcha->setExpectedHostname($_SERVER['SERVER_NAME'])
            ->setScoreThreshold(0.5)
            ->verify($request->input('protect'), getIp());

        return $response->isSuccess();
    }

    if (setting('captcha_type') === 'graphical') {
        return check(strtolower($request->input('protect'))) === $_SESSION['protect'];
    }

    return false;
}

/**
 * Возвращает уникальное имя
 *
 * @param string $extension
 *
 * @return string
 */
function uniqueName(string $extension = null): string
{
    if ($extension) {
        $extension = '.' . $extension;
    }

    return str_replace('.', '', uniqid('', true)) . $extension;
}

/**
 * Возвращает курсы валют
 *
 * @return string
 */
function getCourses()
{
    $courses = Cache::remember('courses', 3600, static function () {
        $curl = new Curl();
        $curl->setConnectTimeout(3);

        $query = $curl->get('https://www.cbr-xml-daily.ru/daily_json.js');

        return $query ? json_decode($query, true) : null;
    });

    return view('app/_courses', compact('courses'));
}

/**
 * Runs the console command
 *
 * @param Command $command
 * @param array   $arguments
 *
 * @return void
 */
function runCommand(Command $command, array $arguments = [])
{
    $input  = new ArrayInput($arguments);
    $output = new NullOutput();

    try {
        $command->run($input, $output);
    } catch (Exception $e) {
        return;
    }
}

/**
 * Returns csrf token field
 *
 * @return string
 */
function csrf_field(): string
{
    return '<input type="hidden" name="token" value="' . $_SESSION['token'] . '">';
}

/**
 * Return config
 *
 * @param string $key
 * @param mixed $default
 *
 * @return mixed
 */
function config(string $key, $default = null)
{
    static $config;

    if (! $config) {
        $configPath = STORAGE . '/caches/config.php';

        if (file_exists($configPath)) {
            $config = require $configPath;
        } else {
            $loader = new Loader(BASEDIR . '/.env');
            $params = $loader->parse()->toArray();
            $getenv = array_intersect_key(getenv(), $params);
            $config = array_replace($params, $getenv);

            if (config('APP_ENV') === 'production') {
                file_put_contents(
                    $configPath, '<?php return ' . var_export($config, true) . ';'
                );
            }
        }
    }

    return $config[$key] ?? $default;
}
